name property

  1. @override
String get name
override

The tab's label, shown in the tab bar and as the console app bar title while this plugin is active.

Implementation

@override
String get name => 'Storage';