defaultMaxEntries constant
int
const defaultMaxEntries
Retention cap used when neither the constructor nor the config sets one.
Implementation
static const int defaultMaxEntries = 2000;
Retention cap used when neither the constructor nor the config sets one.
static const int defaultMaxEntries = 2000;