errorCount property
Incremented each time an error-level entry is added. Never decremented, so the FAB badge always reflects the total error count for the session.
Implementation
static final ValueNotifier<int> errorCount = ValueNotifier(0);
Incremented each time an error-level entry is added. Never decremented, so the FAB badge always reflects the total error count for the session.
static final ValueNotifier<int> errorCount = ValueNotifier(0);