buildConfig method

Widget? buildConfig(
  1. BuildContext context
)

An optional settings panel, toggled by the tune icon in the console app bar while this plugin is active. Return null (the default) if the plugin has nothing to configure.

Implementation

Widget? buildConfig(BuildContext context) => null;