name property
String
get
name
The tab's label, shown in the tab bar and as the console app bar title while this plugin is active.
Implementation
String get name;
The tab's label, shown in the tab bar and as the console app bar title while this plugin is active.
String get name;