reset static method
Clears the measurement so start can be called again. Test-only.
Implementation
@visibleForTesting
static void reset() {
_stopwatch
..stop()
..reset();
_coldStart = null;
version.value++;
}
Clears the measurement so start can be called again. Test-only.
@visibleForTesting
static void reset() {
_stopwatch
..stop()
..reset();
_coldStart = null;
version.value++;
}