JankFrame class

A single frame that missed the budget.

Constructors

JankFrame({required Duration build, required Duration raster, DateTime? at})
Creates a jank frame record.

Properties

at DateTime
When this frame was recorded. Defaults to DateTime.now if omitted.
final
build Duration
Time spent in the build phase.
final
hashCode int
The hash code for this object.
no setterinherited
raster Duration
Time spent in the raster phase.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total Duration
build plus raster — the frame's total time.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited