routeVersion property
Bumped on every navigation event and clear, so the Routes tab can rebuild.
Implementation
static final ValueNotifier<int> routeVersion = ValueNotifier(0);
Bumped on every navigation event and clear, so the Routes tab can rebuild.
static final ValueNotifier<int> routeVersion = ValueNotifier(0);