isFatal property
True when the error was caught by PlatformDispatcher.onError (i.e. an
unhandled async error that would normally terminate the isolate).
Implementation
final bool isFatal;
True when the error was caught by PlatformDispatcher.onError (i.e. an
unhandled async error that would normally terminate the isolate).
final bool isFatal;