source property
Free-form label for where the link came from (e.g. 'push',
'universal_link'), shown in the detail view when present.
Implementation
final String? source;
Free-form label for where the link came from (e.g. 'push',
'universal_link'), shown in the detail view when present.
final String? source;