duration property
How long the route stayed on top of the stack, or null while it is
still the current route.
Implementation
final Duration? duration;
How long the route stayed on top of the stack, or null while it is
still the current route.
final Duration? duration;