DevToolkitPlugin class abstract
Base class for a console tab, whether built in or registered by a
consumer app via FlutterDevToolkit.registerPlugin.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData
-
The tab's icon, shown in the tab bar.
no setter
- name → String
-
The tab's label, shown in the tab bar and as the console app bar title
while this plugin is active.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildActions(
BuildContext context) → List< Widget> - Optional actions to show in the console toolbar
-
buildConfig(
BuildContext context) → Widget? -
An optional settings panel, toggled by the tune icon in the console app
bar while this plugin is active. Return
null(the default) if the plugin has nothing to configure. -
buildTab(
BuildContext context) → Widget - Main UI tab
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onInit(
) → void - Called once when toolkit is initialized
-
onPause(
) → void - Called when app pauses (optional)
-
onResume(
) → void - Called when app resumes from background
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited