RouteEntry class
One entry in a navigation history, recorded by RouteInterceptor.
Constructors
- RouteEntry({required String name, required DateTime entryTime, Duration? duration})
- Creates a route history entry.
Properties
- duration → Duration?
-
How long the route stayed on top of the stack, or
nullwhile it is still the current route.final - entryTime → DateTime
-
When this route was entered.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The route's name, as passed to
Navigator.pushNamedor set viaRouteSettings.name.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this entry for export from the Routes tab.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited