baseTabCount property
How many tabs precede the plugin tabs in the enclosing TabBar. A
selected index below this count means a non-plugin tab is active.
Implementation
final int baseTabCount;
How many tabs precede the plugin tabs in the enclosing TabBar. A
selected index below this count means a non-plugin tab is active.
final int baseTabCount;